==> windows-0.22.1.crate: windows-0.22.1/src/Windows/Win32/System/SubsystemForLinux/mod.rs <==
#![allow(
    unused_variables,
    non_upper_case_globals,
    non_snake_case,
    unused_unsafe,
    non_camel_case_types,
    dead_code,
    clippy::all
)]
#[derive(
    :: std :: cmp :: PartialEq,
    :: std :: cmp :: Eq,
    :: std :: marker :: Copy,
    :: std :: clone :: Clone,
    :: std :: default :: Default,
    :: std :: fmt :: Debug,
)]
#[repr(transparent)]
pub struct WSL_DISTRIBUTION_FLAGS(pub u32);
pub const WSL_DISTRIBUTION_FLAGS_NONE: WSL_DISTRIBUTION_FLAGS = WSL_DISTRIBUTION_FLAGS(0u32);
pub const WSL_DISTRIBUTION_FLAGS_ENABLE_INTEROP: WSL_DISTRIBUTION_FLAGS =
    WSL_DISTRIBUTION_FLAGS(1u32);
pub const WSL_DISTRIBUTION_FLAGS_APPEND_NT_PATH: WSL_DISTRIBUTION_FLAGS =
    WSL_DISTRIBUTION_FLAGS(2u32);
pub const WSL_DISTRIBUTION_FLAGS_ENABLE_DRIVE_MOUNTING: WSL_DISTRIBUTION_FLAGS =
    WSL_DISTRIBUTION_FLAGS(4u32);
impl ::std::convert::From<u32> for WSL_DISTRIBUTION_FLAGS {
    fn from(value: u32) -> Self {
        Self(value)
    }
}
unsafe impl ::windows::runtime::Abi for WSL_DISTRIBUTION_FLAGS {
    type Abi = Self;
    type DefaultType = Self;
}
impl ::std::ops::BitOr for WSL_DISTRIBUTION_FLAGS {
    type Output = Self;
    fn bitor(self, rhs: Self) -> Self {
        Self(self.0 | rhs.0)
    }
}
impl ::std::ops::BitAnd for WSL_DISTRIBUTION_FLAGS {
    type Output = Self;
    fn bitand(self, rhs: Self) -> Self {
        Self(self.0 & rhs.0)
    }
}
impl ::std::ops::BitOrAssign for WSL_DISTRIBUTION_FLAGS {
    fn bitor_assign(&mut self, rhs: Self) {
        self.0.bitor_assign(rhs.0)
    }
}
impl ::std::ops::BitAndAssign for WSL_DISTRIBUTION_FLAGS {
    fn bitand_assign(&mut self, rhs: Self) {
        self.0.bitand_assign(rhs.0)
    }
}
impl ::std::ops::Not for WSL_DISTRIBUTION_FLAGS {
    type Output = Self;
    fn not(self) -> Self {
        Self(self.0.not())
    }
}
#[cfg(feature = "Win32_Foundation")]
pub unsafe fn WslConfigureDistribution<
    'a,
    Param0: ::windows::runtime::IntoParam<'a, super::super::Foundation::PWSTR>,
>(
    distributionname: Param0,
    defaultuid: u32,
    wsldistributionflags: WSL_DISTRIBUTION_FLAGS,
) -> ::windows::runtime::Result<()> {
    #[cfg(windows)]
    {
        #[link(name = "api-ms-win-wsl-api-l1-1-0")]
        extern "system" {
            fn WslConfigureDistribution(
                distributionname: super::super::Foundation::PWSTR,
                defaultuid: u32,
                wsldistributionflags: WSL_DISTRIBUTION_FLAGS,
            ) -> ::windows::runtime::HRESULT;
        }
        WslConfigureDistribution(
            distributionname.into_param().abi(),
            ::std::mem::transmute(defaultuid),
            ::std::mem::transmute(wsldistributionflags),
        )
        .ok()
    }
    #[cfg(not(windows))]
    unimplemented!("Unsupported target OS");
}
#[cfg(feature = "Win32_Foundation")]
pub unsafe fn WslGetDistributionConfiguration<
    'a,
    Param0: ::windows::runtime::IntoParam<'a, super::super::Foundation::PWSTR>,
>(
    distributionname: Param0,
    distributionversion: *mut u32,
    defaultuid: *mut u32,
    wsldistributionflags: *mut WSL_DISTRIBUTION_FLAGS,
    defaultenvironmentvariables: *mut *mut super::super::Foundation::PSTR,
    defaultenvironmentvariablecount: *mut u32,
) -> ::windows::runtime::Result<()> {
    #[cfg(windows)]
    {
        #[link(name = "api-ms-win-wsl-api-l1-1-0")]
        extern "system" {
            fn WslGetDistributionConfiguration(
                distributionname: super::super::Foundation::PWSTR,
                distributionversion: *mut u32,
                defaultuid: *mut u32,
                wsldistributionflags: *mut WSL_DISTRIBUTION_FLAGS,
                defaultenvironmentvariables: *mut *mut super::super::Foundation::PSTR,
                defaultenvironmentvariablecount: *mut u32,
            ) -> ::windows::runtime::HRESULT;
        }
        WslGetDistributionConfiguration(
            distributionname.into_param().abi(),
            ::std::mem::transmute(distributionversion),
            ::std::mem::transmute(defaultuid),
            ::std::mem::transmute(wsldistributionflags),
            ::std::mem::transmute(defaultenvironmentvariables),
            ::std::mem::transmute(defaultenvironmentvariablecount),
        )
        .ok()
    }
    #[cfg(not(windows))]
    unimplemented!("Unsupported target OS");
}
#[cfg(feature = "Win32_Foundation")]
pub unsafe fn WslIsDistributionRegistered<
    'a,
    Param0: ::windows::runtime::IntoParam<'a, super::super::Foundation::PWSTR>,
>(
    distributionname: Param0,
) -> super::super::Foundation::BOOL {
    #[cfg(windows)]
    {
        #[link(name = "api-ms-win-wsl-api-l1-1-0")]
        extern "system" {
            fn WslIsDistributionRegistered(
                distributionname: super::super::Foundation::PWSTR,
            ) -> super::super::Foundation::BOOL;
        }
        ::std::mem::transmute(WslIsDistributionRegistered(
            distributionname.into_param().abi(),
        ))
    }
    #[cfg(not(windows))]
    unimplemented!("Unsupported target OS");
}
#[cfg(feature = "Win32_Foundation")]
pub unsafe fn WslLaunch<
    'a,
    Param0: ::windows::runtime::IntoParam<'a, super::super::Foundation::PWSTR>,
    Param1: ::windows::runtime::IntoParam<'a, super::super::Foundation::PWSTR>,
    Param2: ::windows::runtime::IntoParam<'a, super::super::Foundation::BOOL>,
    Param3: ::windows::runtime::IntoParam<'a, super::super::Foundation::HANDLE>,
    Param4: ::windows::runtime::IntoParam<'a, super::super::Foundation::HANDLE>,
    Param5: ::windows::runtime::IntoParam<'a, super::super::Foundation::HANDLE>,
>(
    distributionname: Param0,
    command: Param1,
    usecurrentworkingdirectory: Param2,
    stdin: Param3,
    stdout: Param4,
    stderr: Param5,
) -> ::windows::runtime::Result<super::super::Foundation::HANDLE> {
    #[cfg(windows)]
    {
        #[link(name = "api-ms-win-wsl-api-l1-1-0")]
        extern "system" {
            fn WslLaunch(
                distributionname: super::super::Foundation::PWSTR,
                command: super::super::Foundation::PWSTR,
                usecurrentworkingdirectory: super::super::Foundation::BOOL,
                stdin: super::super::Foundation::HANDLE,
                stdout: super::super::Foundation::HANDLE,
                stderr: super::super::Foundation::HANDLE,
                process: *mut super::super::Foundation::HANDLE,
            ) -> ::windows::runtime::HRESULT;
        }
        let mut result__: <super::super::Foundation::HANDLE as ::windows::runtime::Abi>::Abi =
            ::std::mem::zeroed();
        WslLaunch(
            distributionname.into_param().abi(),
            command.into_param().abi(),
            usecurrentworkingdirectory.into_param().abi(),
            stdin.into_param().abi(),
            stdout.into_param().abi(),
            stderr.into_param().abi(),
            &mut result__,
        )
        .from_abi::<super::super::Foundation::HANDLE>(result__)
    }
    #[cfg(not(windows))]
    unimplemented!("Unsupported target OS");
}
#[cfg(feature = "Win32_Foundation")]
pub unsafe fn WslLaunchInteractive<
    'a,
    Param0: ::windows::runtime::IntoParam<'a, super::super::Foundation::PWSTR>,
    Param1: ::windows::runtime::IntoParam<'a, super::super::Foundation::PWSTR>,
    Param2: ::windows::runtime::IntoParam<'a, super::super::Foundation::BOOL>,
>(
    distributionname: Param0,
    command: Param1,
    usecurrentworkingdirectory: Param2,
) -> ::windows::runtime::Result<u32> {
    #[cfg(windows)]
    {
        #[link(name = "api-ms-win-wsl-api-l1-1-0")]
        extern "system" {
            fn WslLaunchInteractive(
                distributionname: super::super::Foundation::PWSTR,
                command: super::super::Foundation::PWSTR,
                usecurrentworkingdirectory: super::super::Foundation::BOOL,
                exitcode: *mut u32,
            ) -> ::windows::runtime::HRESULT;
        }
        let mut result__: <u32 as ::windows::runtime::Abi>::Abi = ::std::mem::zeroed();
        WslLaunchInteractive(
            distributionname.into_param().abi(),
            command.into_param().abi(),
            usecurrentworkingdirectory.into_param().abi(),
            &mut result__,
        )
        .from_abi::<u32>(result__)
    }
    #[cfg(not(windows))]
    unimplemented!("Unsupported target OS");
}
#[cfg(feature = "Win32_Foundation")]
pub unsafe fn WslRegisterDistribution<
    'a,
    Param0: ::windows::runtime::IntoParam<'a, super::super::Foundation::PWSTR>,
    Param1: ::windows::runtime::IntoParam<'a, super::super::Foundation::PWSTR>,
>(
    distributionname: Param0,
    targzfilename: Param1,
) -> ::windows::runtime::Result<()> {
    #[cfg(windows)]
    {
        #[link(name = "api-ms-win-wsl-api-l1-1-0")]
        extern "system" {
            fn WslRegisterDistribution(
                distributionname: super::super::Foundation::PWSTR,
                targzfilename: super::super::Foundation::PWSTR,
            ) -> ::windows::runtime::HRESULT;
        }
        WslRegisterDistribution(
            distributionname.into_param().abi(),
            targzfilename.into_param().abi(),
        )
        .ok()
    }
    #[cfg(not(windows))]
    unimplemented!("Unsupported target OS");
}
#[cfg(feature = "Win32_Foundation")]
pub unsafe fn WslUnregisterDistribution<
    'a,
    Param0: ::windows::runtime::IntoParam<'a, super::super::Foundation::PWSTR>,
>(
    distributionname: Param0,
) -> ::windows::runtime::Result<()> {
    #[cfg(windows)]
    {
        #[link(name = "api-ms-win-wsl-api-l1-1-0")]
        extern "system" {
            fn WslUnregisterDistribution(
                distributionname: super::super::Foundation::PWSTR,
            ) -> ::windows::runtime::HRESULT;
        }
        WslUnregisterDistribution(distributionname.into_param().abi()).ok()
    }
    #[cfg(not(windows))]
    unimplemented!("Unsupported target OS");
}

==> windows-0.23.0.crate: windows-0.23.0/src/Windows/Win32/System/SubsystemForLinux/mod.rs <==
#![allow(
    unused_variables,
    non_upper_case_globals,
    non_snake_case,
    unused_unsafe,
    non_camel_case_types,
    dead_code,
    clippy::all
)]
#[derive(
    :: std :: cmp :: PartialEq,
    :: std :: cmp :: Eq,
    :: std :: marker :: Copy,
    :: std :: clone :: Clone,
    :: std :: default :: Default,
    :: std :: fmt :: Debug,
)]
#[repr(transparent)]
pub struct WSL_DISTRIBUTION_FLAGS(pub u32);
pub const WSL_DISTRIBUTION_FLAGS_NONE: WSL_DISTRIBUTION_FLAGS = WSL_DISTRIBUTION_FLAGS(0u32);
pub const WSL_DISTRIBUTION_FLAGS_ENABLE_INTEROP: WSL_DISTRIBUTION_FLAGS =
    WSL_DISTRIBUTION_FLAGS(1u32);
pub const WSL_DISTRIBUTION_FLAGS_APPEND_NT_PATH: WSL_DISTRIBUTION_FLAGS =
    WSL_DISTRIBUTION_FLAGS(2u32);
pub const WSL_DISTRIBUTION_FLAGS_ENABLE_DRIVE_MOUNTING: WSL_DISTRIBUTION_FLAGS =
    WSL_DISTRIBUTION_FLAGS(4u32);
impl ::std::convert::From<u32> for WSL_DISTRIBUTION_FLAGS {
    fn from(value: u32) -> Self {
        Self(value)
    }
}
unsafe impl ::windows::runtime::Abi for WSL_DISTRIBUTION_FLAGS {
    type Abi = Self;
    type DefaultType = Self;
}
impl ::std::ops::BitOr for WSL_DISTRIBUTION_FLAGS {
    type Output = Self;
    fn bitor(self, rhs: Self) -> Self {
        Self(self.0 | rhs.0)
    }
}
impl ::std::ops::BitAnd for WSL_DISTRIBUTION_FLAGS {
    type Output = Self;
    fn bitand(self, rhs: Self) -> Self {
        Self(self.0 & rhs.0)
    }
}
impl ::std::ops::BitOrAssign for WSL_DISTRIBUTION_FLAGS {
    fn bitor_assign(&mut self, rhs: Self) {
        self.0.bitor_assign(rhs.0)
    }
}
impl ::std::ops::BitAndAssign for WSL_DISTRIBUTION_FLAGS {
    fn bitand_assign(&mut self, rhs: Self) {
        self.0.bitand_assign(rhs.0)
    }
}
impl ::std::ops::Not for WSL_DISTRIBUTION_FLAGS {
    type Output = Self;
    fn not(self) -> Self {
        Self(self.0.not())
    }
}
#[cfg(feature = "Win32_Foundation")]
pub unsafe fn WslConfigureDistribution<
    'a,
    Param0: ::windows::runtime::IntoParam<'a, super::super::Foundation::PWSTR>,
>(
    distributionname: Param0,
    defaultuid: u32,
    wsldistributionflags: WSL_DISTRIBUTION_FLAGS,
) -> ::windows::runtime::Result<()> {
    #[cfg(windows)]
    {
        #[link(name = "windows")]
        extern "system" {
            fn WslConfigureDistribution(
                distributionname: super::super::Foundation::PWSTR,
                defaultuid: u32,
                wsldistributionflags: WSL_DISTRIBUTION_FLAGS,
            ) -> ::windows::runtime::HRESULT;
        }
        WslConfigureDistribution(
            distributionname.into_param().abi(),
            ::std::mem::transmute(defaultuid),
            ::std::mem::transmute(wsldistributionflags),
        )
        .ok()
    }
    #[cfg(not(windows))]
    unimplemented!("Unsupported target OS");
}
#[cfg(feature = "Win32_Foundation")]
pub unsafe fn WslGetDistributionConfiguration<
    'a,
    Param0: ::windows::runtime::IntoParam<'a, super::super::Foundation::PWSTR>,
>(
    distributionname: Param0,
    distributionversion: *mut u32,
    defaultuid: *mut u32,
    wsldistributionflags: *mut WSL_DISTRIBUTION_FLAGS,
    defaultenvironmentvariables: *mut *mut super::super::Foundation::PSTR,
    defaultenvironmentvariablecount: *mut u32,
) -> ::windows::runtime::Result<()> {
    #[cfg(windows)]
    {
        #[link(name = "windows")]
        extern "system" {
            fn WslGetDistributionConfiguration(
                distributionname: super::super::Foundation::PWSTR,
                distributionversion: *mut u32,
                defaultuid: *mut u32,
                wsldistributionflags: *mut WSL_DISTRIBUTION_FLAGS,
                defaultenvironmentvariables: *mut *mut super::super::Foundation::PSTR,
                defaultenvironmentvariablecount: *mut u32,
            ) -> ::windows::runtime::HRESULT;
        }
        WslGetDistributionConfiguration(
            distributionname.into_param().abi(),
            ::std::mem::transmute(distributionversion),
            ::std::mem::transmute(defaultuid),
            ::std::mem::transmute(wsldistributionflags),
            ::std::mem::transmute(defaultenvironmentvariables),
            ::std::mem::transmute(defaultenvironmentvariablecount),
        )
        .ok()
    }
    #[cfg(not(windows))]
    unimplemented!("Unsupported target OS");
}
#[cfg(feature = "Win32_Foundation")]
pub unsafe fn WslIsDistributionRegistered<
    'a,
    Param0: ::windows::runtime::IntoParam<'a, super::super::Foundation::PWSTR>,
>(
    distributionname: Param0,
) -> super::super::Foundation::BOOL {
    #[cfg(windows)]
    {
        #[link(name = "windows")]
        extern "system" {
            fn WslIsDistributionRegistered(
                distributionname: super::super::Foundation::PWSTR,
            ) -> super::super::Foundation::BOOL;
        }
        ::std::mem::transmute(WslIsDistributionRegistered(
            distributionname.into_param().abi(),
        ))
    }
    #[cfg(not(windows))]
    unimplemented!("Unsupported target OS");
}
#[cfg(feature = "Win32_Foundation")]
pub unsafe fn WslLaunch<
    'a,
    Param0: ::windows::runtime::IntoParam<'a, super::super::Foundation::PWSTR>,
    Param1: ::windows::runtime::IntoParam<'a, super::super::Foundation::PWSTR>,
    Param2: ::windows::runtime::IntoParam<'a, super::super::Foundation::BOOL>,
    Param3: ::windows::runtime::IntoParam<'a, super::super::Foundation::HANDLE>,
    Param4: ::windows::runtime::IntoParam<'a, super::super::Foundation::HANDLE>,
    Param5: ::windows::runtime::IntoParam<'a, super::super::Foundation::HANDLE>,
>(
    distributionname: Param0,
    command: Param1,
    usecurrentworkingdirectory: Param2,
    stdin: Param3,
    stdout: Param4,
    stderr: Param5,
) -> ::windows::runtime::Result<super::super::Foundation::HANDLE> {
    #[cfg(windows)]
    {
        #[link(name = "windows")]
        extern "system" {
            fn WslLaunch(
                distributionname: super::super::Foundation::PWSTR,
                command: super::super::Foundation::PWSTR,
                usecurrentworkingdirectory: super::super::Foundation::BOOL,
                stdin: super::super::Foundation::HANDLE,
                stdout: super::super::Foundation::HANDLE,
                stderr: super::super::Foundation::HANDLE,
                process: *mut super::super::Foundation::HANDLE,
            ) -> ::windows::runtime::HRESULT;
        }
        let mut result__: <super::super::Foundation::HANDLE as ::windows::runtime::Abi>::Abi =
            ::std::mem::zeroed();
        WslLaunch(
            distributionname.into_param().abi(),
            command.into_param().abi(),
            usecurrentworkingdirectory.into_param().abi(),
            stdin.into_param().abi(),
            stdout.into_param().abi(),
            stderr.into_param().abi(),
            &mut result__,
        )
        .from_abi::<super::super::Foundation::HANDLE>(result__)
    }
    #[cfg(not(windows))]
    unimplemented!("Unsupported target OS");
}
#[cfg(feature = "Win32_Foundation")]
pub unsafe fn WslLaunchInteractive<
    'a,
    Param0: ::windows::runtime::IntoParam<'a, super::super::Foundation::PWSTR>,
    Param1: ::windows::runtime::IntoParam<'a, super::super::Foundation::PWSTR>,
    Param2: ::windows::runtime::IntoParam<'a, super::super::Foundation::BOOL>,
>(
    distributionname: Param0,
    command: Param1,
    usecurrentworkingdirectory: Param2,
) -> ::windows::runtime::Result<u32> {
    #[cfg(windows)]
    {
        #[link(name = "windows")]
        extern "system" {
            fn WslLaunchInteractive(
                distributionname: super::super::Foundation::PWSTR,
                command: super::super::Foundation::PWSTR,
                usecurrentworkingdirectory: super::super::Foundation::BOOL,
                exitcode: *mut u32,
            ) -> ::windows::runtime::HRESULT;
        }
        let mut result__: <u32 as ::windows::runtime::Abi>::Abi = ::std::mem::zeroed();
        WslLaunchInteractive(
            distributionname.into_param().abi(),
            command.into_param().abi(),
            usecurrentworkingdirectory.into_param().abi(),
            &mut result__,
        )
        .from_abi::<u32>(result__)
    }
    #[cfg(not(windows))]
    unimplemented!("Unsupported target OS");
}
#[cfg(feature = "Win32_Foundation")]
pub unsafe fn WslRegisterDistribution<
    'a,
    Param0: ::windows::runtime::IntoParam<'a, super::super::Foundation::PWSTR>,
    Param1: ::windows::runtime::IntoParam<'a, super::super::Foundation::PWSTR>,
>(
    distributionname: Param0,
    targzfilename: Param1,
) -> ::windows::runtime::Result<()> {
    #[cfg(windows)]
    {
        #[link(name = "windows")]
        extern "system" {
            fn WslRegisterDistribution(
                distributionname: super::super::Foundation::PWSTR,
                targzfilename: super::super::Foundation::PWSTR,
            ) -> ::windows::runtime::HRESULT;
        }
        WslRegisterDistribution(
            distributionname.into_param().abi(),
            targzfilename.into_param().abi(),
        )
        .ok()
    }
    #[cfg(not(windows))]
    unimplemented!("Unsupported target OS");
}
#[cfg(feature = "Win32_Foundation")]
pub unsafe fn WslUnregisterDistribution<
    'a,
    Param0: ::windows::runtime::IntoParam<'a, super::super::Foundation::PWSTR>,
>(
    distributionname: Param0,
) -> ::windows::runtime::Result<()> {
    #[cfg(windows)]
    {
        #[link(name = "windows")]
        extern "system" {
            fn WslUnregisterDistribution(
                distributionname: super::super::Foundation::PWSTR,
            ) -> ::windows::runtime::HRESULT;
        }
        WslUnregisterDistribution(distributionname.into_param().abi()).ok()
    }
    #[cfg(not(windows))]
    unimplemented!("Unsupported target OS");
}
